//______________________________________________________________________________

//            Hlavikov soubor knihovny TPCI1052.DLL verze 1.00

//                         (c) TEDIA, 13.1.2004
//______________________________________________________________________________

unit Tpci1052;

interface
uses Windows, Classes, SysUtils, Wintypes;



//______________________________________________________________ NAVRATOVE KODY


//    0     V podku
//    1     Chybn komunikan rychlost
//    2     Rozdln timeouty nebo rychlosti linek
//    3     Chyba pi vysln zprvy
//    4     Timeout - nepila dn odpov
//    5     Timeout - nepila sprvn odpov
//    6     Odpov peruena
//    7     Chyba parity odpovdi
//    8     Chybn hlavika odpovdi
//    9     Chyba CRC odpovdi
//   10     Nelze vytvoit datovou strukturu knihovny
//   11     Neplatn handle zazen
//   12     Nenalezena karta PCI-1052
//   13     Nen otevena dn karta PCI-1052
//   14     Zazen ji inicializovno
//   15     Chyba knihovny TEDIA_OX9162
//   16     Chyba knihovny TEDIA_OX9162 (Card_DID)
//   17     Chyba knihovny TEDIA_OX9162 (Card_BUS)
//   18     Chyba knihovny TEDIA_OX9162 (Card_SLOT)
//   19     Chyba knihovny TEDIA_OX9162 (CardsInSystem)
//   20     Chyba knihovny TEDIA_OX9162 (Open)
//   21     Chyba knihovny TEDIA_OX9162 (Close)
//   22     Chyba knihovny TEDIA_OX9162 (BAR4_BaseAdr)
//   23     Chyba karty PCI-1052
//   24     Chyba karty PCI-1052 (restart)
//   25     Chyba karty PCI-1052 (pepnut reimu)
//   26     Chyba karty PCI-1052 (ten z DPRAM)
//   27     Chyba karty PCI-1052 (zpis do DPRAM)
//   28     Chyba karty PCI-1052 (proveden povelu)


//_______________________________________________________________ DEFINICE TYPU

type
  Buff     = array[0..99] of DWord;  // pole DWord (100 prvku)
  PBuff    = ^Buff;                  // ukazatel na pole DWord



//_____________________________________________________________ EXPORTOVANE FCE

// Vsechny funkce vraci 0 v pripade uspesneho provedeni. Nenulova hodnota
// signalizuje chybu, pro jeji identifikaci lze pouzit funkci TPCI1052_Error.


function TPCI1052_Version(Ver:PDWord):DWord;                                     stdcall;
// Vraci verzi knihovny DLL (nutno vydelit 100, napr. vracena hodnota 123
// znamena verzi 1.23).

function TPCI1052_Init(PHNDL:PDWord):DWord;                                      stdcall;
// Inicializuje knihovnu, vyhleda a otevre prvni nalezenou kartu PCI-1052.
// Nastavi default komunikacni parametry (9600Bd, timeout 15ms, 2 opakovani
// pri chybe). Vraci handle otevreneho zarizeni.

function TPCI1052_SetConfig(HNDL:DWord;Baud,Timeout,Opakovani:DWord):DWord;      stdcall;
// Nastavi komunikacni rychlost, timeout a opakovani pro komunikaci
// s moduly MicroUnit. Povolene rychlosti odpovidaji modulum MicroUnit,
// tj. 600Bd, 1200Bd, 2400Bd, 4800Bd, 9600Bd, 19200Bd, 38400Bd, 57600Bd
// a 115200Bd. Timeout, tj. max. doba cekani na zahajeni odpovedi modulu,
// je nastavitelny od 1 do 10000ms. Opakovani urcuje pocet zopakovanych volani
// na modul MicroUnit v pripade chybne komunikace, tzn. napr. pro Opakovani=2
// je na modul MicroUnit volani v pripade chyby komunikace celkem 3x.
// Pokud vyhovi default hodnoty konfigurace (viz. TPCI1052_Init), neni nutno
// tuto funkci volat.

function TPCI1052_GetConfig(HNDL:DWord;Baud,Timeout,Opakovani:PDWord):DWord;     stdcall;
// Vraci nastavenou komunikacni rychlost, timeout a opakovani pro komunikaci
// s moduly MicroUnit.

function TPCI1052_Send(HNDL:DWord;TBuff,RBuff:PBuff;StatusR,StatusP:PDWord):DWord; stdcall;
// Vysle dotaz (TBuff) na modul MicroUnit, vrati odpoved modulu (RBuff),
// Status registr modulu (StatusR) a Status prijmu (StatusP).
// TBuff a RBuff jsou pole obsahujici vyslanou resp. prijatou zpravu.
// Obsah TBuff odpovida vysilane zprave protokolu AIBus-2, bez CRC. Presny
// vyznam je uveden v popisu protokolu.
//  TBuff[0] - adresa volaneho modulu MicroUnit (0-255)
//  TBuff[1] - pozadovana funkce AIBus-2 (0,1,2,3,100,101,102,103,200)
//  TBuff[2] - pozadovana periferie modulu MicroUnit (0-255)
//  TBuff[3] - primy povel (0)
//  TBuff[4] - D1 datovy byte dotazu (0-255)
//  TBuff[5] - D2 datovy byte dotazu (0-255)
//  TBuff[6] - D3 datovy byte dotazu (0-255)
//  TBuff[7] - D4 datovy byte dotazu (0-255)
// Pole RBuff obsahuje pouze prijate datove byty odpovedi.
//  RBuff[0] - D1 datovy byte odpovedi (0-255)
//  RBuff[1] - D1 datovy byte odpovedi (0-255)
//  RBuff[2] - D1 datovy byte odpovedi (0-255)
//  RBuff[3] - D1 datovy byte odpovedi (0-255)
// StatusR obsahuje prijaty Status registr modulu.
// Ve StatusP je ulozen kod uspesnosti komunikace s modulem MicroUnit.
// Slovni popis kodu lze ziskat pomoci funkce TPCI1052_Error.

function TPCI1052_Done(PHNDL:PDWord):DWord;                                      stdcall;
// Uzavre otevrenou kartu PCI-1052 a uvolni knihovnu z pameti.

function TPCI1052_Error(ErrCode:DWord; ErrText:PBuff):DWord;                     stdcall;
// Prevede navratovy kod na text.

//________________________________________________________________ IMPLEMENTACE

implementation


//______________________________________________________________________________

function TPCI1052_Version;                             external 'TPCI1052.DLL';
function TPCI1052_Init;                                external 'TPCI1052.DLL';
function TPCI1052_SetConfig;                           external 'TPCI1052.DLL';
function TPCI1052_GetConfig;                           external 'TPCI1052.DLL';
function TPCI1052_Send;                                external 'TPCI1052.DLL';
function TPCI1052_Done;                                external 'TPCI1052.DLL';
function TPCI1052_Error;                               external 'TPCI1052.DLL';

//______________________________________________________________________________

begin
end.


